#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# Xiang Wang @ 2019-05-10 16:47:20


import io

from PIL import Image, ImageColor, ImageDraw
import requests


def convert_image(from_image, to_image, background, frontcolor):
    # TODO add comment
    raise Exception("please complete the mask function first")
    img = Image.open(from_image)
    image_size = img.size
    img = img.resize(image_size)
    img = img.convert(mode="L")
    img = Image.eval(img, exclude_black_and_white)
    result = Image.new("RGBA", image_size, background)
    yellow = Image.new("RGBA", image_size, frontcolor)
    result.paste(yellow, (0, 0), mask=img)
    result.save(to_image)


def circle_image(from_image):
    """
    create the circle image from a square ImageClass
    """
    image_size = from_image.size
    assert image_size[0] == image_size[1], "The image has different dimension"
    image = Image.new("RGBA", image_size, "#00000000")
    draw = ImageDraw.Draw(image)
    draw.chord(
        ((0,0), image_size),
        0, 360,
        outline="#FF0000",
        fill="#00FF00",
        width=3,)
    image.paste(from_image, (0,0), image)
    return image



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# Xiang Wang @ 2019-05-21 10:59:50


from PIL import Image

"""
create a mask from an image
"""


class Mask(object):

    def __init__(self, image):
        self.image = image
        self.image_grey = image.convert(mode="L")
        self.size = image.size

    def create_transparent_image(self):
        return self.create_colorful_image("#00000000")

    def create_colorful_image(self, color):
        image = Image.new("RGBA", self.size, color)
        return image

    def get_exclude_white_image(self, tolerance=1):
        threshold = 255 - tolerance
        image = self.create_transparent_image()

        def exclude_white(x):
            if x > threshold:
                return 0
            return 255

        mask = Image.eval(self.image_grey, exclude_white)
        image.paste(self.image, (0,0), mask)
        return image

    def convert_to_single_color(
            self, color, background="#00000000", mode="L"):
        """
        convert the color to a single color image
        params: mode
            L: according the image's brightness
            opacity: according the image's opacity
        """
        bg_image = self.create_colorful_image(background)
        colorful_image = self.create_colorful_image(color)
        if mode == "L":
            bg_image.paste(colorful_image, (0, 0), self.image_grey)
        elif mode == "opacity":
            bg_image.paste(colorful_image, (0, 0), self.image)
        else:
            raise NotImplementedError("the mode can't be recognized")
        return bg_image



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# Xiang Wang @ 2019-05-20 17:42:16

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pillow-snippet",
    version="0.0.4",
    author="Xiang Wang",
    author_email="ramwin@qq.com",
    description="some useful snippet for image",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ramwin/pillow_snippet",
    packages=setuptools.find_packages(),
    install_requires=[
        "pillow",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
